"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const compare_url_1 = require("./compare-url");
describe('compareUrl()', () => {
    it('should return true for the same url', () => {
        const res = compare_url_1.compareUrl('/pricing', '/pricing');
        chai_1.expect(res).to.be.true;
    });
    it('should match sub url', () => {
        const res = compare_url_1.compareUrl('/pricing/offer', '/pricing');
        chai_1.expect(res).to.be.true;
    });
    it('should not match sub url when strict', () => {
        const res = compare_url_1.compareUrl('/pricing/offer', '/pricing', { exact: true });
        chai_1.expect(res).to.be.false;
    });
    it('should ignore trailing slash by default', () => {
        const res = compare_url_1.compareUrl('/pricing/', '/pricing');
        chai_1.expect(res).to.be.true;
    });
    it('should match trailing slash when strict', () => {
        const res = compare_url_1.compareUrl('/pricing/', '/pricing', { strict: true });
        chai_1.expect(res).to.be.false;
    });
    it('should not match when query params not equal', () => {
        const res = compare_url_1.compareUrl('/pricing?deal=true', '/pricing?deal=yes');
        chai_1.expect(res).to.be.false;
    });
    it('should match when query params equal', () => {
        const res = compare_url_1.compareUrl('/pricing?deal=yes', '/pricing?deal=yes');
        chai_1.expect(res).to.be.true;
    });
    it('should match when query params are a subset', () => {
        const res = compare_url_1.compareUrl('/pricing?deal=yes&offer=yes', '/pricing?deal=yes');
        chai_1.expect(res).to.be.true;
    });
    it('should not match unequal query when exact', () => {
        const res = compare_url_1.compareUrl('/pricing?deal=yes&offer=yes', '/pricing?deal=yes', {
            exact: true,
        });
        chai_1.expect(res).to.be.false;
    });
    it('should match by hash', () => {
        const res = compare_url_1.compareUrl('/pricing#faq', '#faq');
        chai_1.expect(res).to.be.true;
    });
    it('should ignore trailing slash in base when exact but not strict', () => {
        const res = compare_url_1.compareUrl('/pricing/', '/pricing', { exact: true });
        chai_1.expect(res).to.be.true;
    });
    it('should ignore trailing slash in match when exact but not strict', () => {
        const res = compare_url_1.compareUrl('/pricing', '/pricing/', { exact: true });
        chai_1.expect(res).to.be.true;
    });
    it('should ignore trailing slash when having query params', () => {
        const res = compare_url_1.compareUrl('/pricing?offer=yes', '/pricing/');
        chai_1.expect(res).to.be.true;
    });
    it('should ignore trailing slash when having hash', () => {
        const res = compare_url_1.compareUrl('/pricing#special-offer', '/pricing/');
        chai_1.expect(res).to.be.true;
    });
    // this most definitely does not cover all cases.
    // we should try to follow the same implementation as react-router
});
//# sourceMappingURL=compare-url.spec.js.map